nengo\_spa\.pointer
===================

.. automodule:: nengo_spa.pointer
   :exclude-members: SemanticPointer
   :show-inheritance:

   .. rubric:: Classes

   .. autosummary::

      AbsorbingElement
      Identity
      SemanticPointer
      Zero

   .. autoclass:: SemanticPointer
      :exclude-members: connect_to, construct, evaluate
